#
# spec file for package ghc-profunctors
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name profunctors
Name:           ghc-%{pkg_name}
Version:        5.3
Release:        2.4
Summary:        Profunctors
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-contravariant-devel
BuildRequires:  ghc-distributive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroups-devel
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-transformers-devel

%description
Profunctors.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update profunctors to version 5.3.
  5.3 [2018.07.02]
  - ---------------
  * Generalize the types of `(#.)` and `(.#)`. Before, they were:
    ```haskell
    (#.) :: (Profunctor p, Coercible c b) => (b -> c) -> p a b    -> p a c
    (.#) :: (Profunctor p, Coercible b a) => p b c    -> (a -> b) -> p a c
    ```
    Now, they are:
    ```haskell
    (#.) :: (Profunctor p, Coercible c b) => q b c    -> p a b    -> p a c
    (.#) :: (Profunctor p, Coercible b a) => p b c    -> q a b    -> p a c
    ```
  * Drop support for GHC < 7.8.
  * Add a `Profunctor` instance for `Data.Bifunctor.Sum`.
* Mon May 14 2018 psimons@suse.com
- Update profunctors to version 5.2.2 revision 1.
  * Add `Semigroup` instances for `Closure` and `Tambara`
  * Allow `base-orphans-0.6`.
  * Add `Traversing` instance for `Forget`
  * Add `Traversing` and `Mapping` instances for `Procompose`
  * Add `Category` instance for `Star`
  * Add `mapCayley` to `Data.Profunctor.Cayley`
  * Add `pastro` and `unpastro` to `Data.Profunctor.Strong`.
  * Add `dimapWandering`, `lmapWandering`, and `rmapWandering` to `Data.Profunctor.Traversing`
  * Add documentation stating the laws for various profunctors.
  * Introduce the `Data.Profunctor.Yoneda` module.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 5.2 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 5.2 revision 0 with cabal2obs.
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 5.2
  * Renamed Cotambara to TambaraChoice and Pastro to PastroChoice.
  * Added a true Cotambara and Copastro construction for (co)freely generating
    costrength, along with CotambaraSum and CopastroSum variants.
  * Engaged in a fair bit of bikeshedding about the module structure for lesser used
    modules in this package.
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 5.1.2
  * Added Prep and Coprep along with witnesses to the adjunctions
  Prep -| Star : [Hask,Hask] -> Prof and Coprep -| Costar : [Hask,Hask]^op -> Prof.
* Thu Aug  6 2015 mimi.vx@gmail.com
- update to 5.1.1
  * Add proper support for GHC 7.0+.
  * instance Costrong (Cokleisli f).
  * instance Cochoice (Star f).
  * Changed the instance for Cochoice (Costar f).
  * MINIMAL pragma for Costrong and Cochoice.
  * More Costrong and Cochoice instances.
  * UpStar and DownStar have become Star and Costar. Star is analogous to Kleisli,
  Costar is analogous to Cokleisli.
  * Split representability into sieves and representability.
  * Moved Data.Profunctor.Collage to semigroupoids 5, and removed the semigroupoids
  dependency.
* Sun Apr 26 2015 mimi.vx@gmail.com
- initial commit
